@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2012 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2014 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -27,7 +27,7 @@ namespace drumstick {
     class SequencerEvent;
 };
 
-#include <alsaclient.h>
+#include <drumstick/alsaclient.h>
 
 class DrumGridModel;
 
@@ -90,7 +90,8 @@ public:
 
     void sendControlChange( int cc, int value );
     void sendInitialControls();
-    
+    void retranslateUi();
+
     void metronome_start();
     void metronome_stop();
     void metronome_continue();
